==> get-3.25.2.tar.gz: lib/get_connect/http/src/http/html/http_request_html.dart <==
import 'dart:async';
import 'dart:html' as html;
import 'dart:typed_data';

import '../../certificates/certificates.dart';
import '../../exceptions/exceptions.dart';
import '../../request/request.dart';
import '../../response/response.dart';
import '../interface/request_base.dart';
import '../utils/body_decoder.dart';

/// A `dart:html` implementation of `HttpRequestBase`.
class HttpRequestImpl implements HttpRequestBase {
  HttpRequestImpl({
    bool allowAutoSignedCert = true,
    List<TrustedCertificate> trustedCertificates,
  });

  /// The currently active XHRs.
  final _xhrs = <html.HttpRequest>{};

  ///This option requires that you submit credentials for requests
  ///on different sites. The default is false
  bool withCredentials = false;

  /// Sends an HTTP request and asynchronously returns the response.
  @override
  Future<Response<T>> send<T>(Request<T> request) async {
    var bytes = await request.bodyBytes.toBytes();
    html.HttpRequest xhr;

    xhr = html.HttpRequest()
      ..open(request.method, '${request.url}', async: true); // check this

    _xhrs.add(xhr);

    xhr
      ..responseType = 'blob'
      ..withCredentials = withCredentials;
    request.headers.forEach(xhr.setRequestHeader);

    var completer = Completer<Response<T>>();
    xhr.onLoad.first.then((_) {
      var blob = xhr.response as html.Blob ?? html.Blob([]);
      var reader = html.FileReader();

      reader.onLoad.first.then((_) async {
        var bodyBytes = BodyBytesStream.fromBytes(reader.result as Uint8List);

        final stringBody =
            await bodyBytesToString(bodyBytes, xhr.responseHeaders);

        String contentType;

        if (xhr.responseHeaders.containsKey('content-type')) {
          contentType = xhr.responseHeaders['content-type'];
        } else {
          contentType = 'application/json';
        }
        // xhr.responseHeaders.containsKey(key)
        final body = bodyDecoded<T>(
          request,
          stringBody,
          contentType,
        );

        final response = Response<T>(
          bodyBytes: bodyBytes,
          statusCode: xhr.status,
          request: request,
          headers: xhr.responseHeaders,
          statusText: xhr.statusText,
          body: body,
          bodyString: stringBody,
        );
        completer.complete(response);
      });

      reader.onError.first.then((error) {
        completer.completeError(
          GetHttpException(error.toString(), request.url),
          StackTrace.current,
        );
      });

      reader.readAsArrayBuffer(blob);
    });

    xhr.onError.first.then((_) {
      completer.completeError(
          GetHttpException('XMLHttpRequest error.', request.url),
          StackTrace.current);
    });

    xhr.send(bytes);

    try {
      return await completer.future;
    } finally {
      _xhrs.remove(xhr);
    }
  }

  /// Closes the client and abort all active requests.
  @override
  void close() {
    for (var xhr in _xhrs) {
      xhr.abort();
    }
  }
}

==> get-4.0.1.tar.gz: lib/get_connect/http/src/http/html/http_request_html.dart <==
import 'dart:async';
import 'dart:html' as html;

import '../../certificates/certificates.dart';
import '../../exceptions/exceptions.dart';
import '../../request/request.dart';
import '../../response/response.dart';
import '../interface/request_base.dart';
import '../utils/body_decoder.dart';

/// A `dart:html` implementation of `HttpRequestBase`.
class HttpRequestImpl implements HttpRequestBase {
  HttpRequestImpl({
    bool allowAutoSignedCert = true,
    List<TrustedCertificate>? trustedCertificates,
  });

  /// The currently active XHRs.
  final _xhrs = <html.HttpRequest>{};

  ///This option requires that you submit credentials for requests
  ///on different sites. The default is false
  bool withCredentials = false;

  /// Sends an HTTP request and asynchronously returns the response.
  @override
  Future<Response<T>> send<T>(Request<T> request) async {
    var bytes = await request.bodyBytes.toBytes();
    html.HttpRequest xhr;

    xhr = html.HttpRequest()
      ..open(request.method, '${request.url}', async: true); // check this

    _xhrs.add(xhr);

    xhr
      ..responseType = 'blob'
      ..withCredentials = withCredentials;
    request.headers.forEach(xhr.setRequestHeader);
    request.contentLength ?? -1;

    var completer = Completer<Response<T>>();
    xhr.onLoad.first.then((_) {
      var blob = xhr.response as html.Blob? ?? html.Blob([]);
      var reader = html.FileReader();

      reader.onLoad.first.then((_) async {
        var bodyBytes = BodyBytesStream.fromBytes(reader.result as List<int>);

        final stringBody =
            await bodyBytesToString(bodyBytes, xhr.responseHeaders);

        String? contentType;

        if (xhr.responseHeaders.containsKey('content-type')) {
          contentType = xhr.responseHeaders['content-type'];
        } else {
          contentType = 'application/json';
        }
        // xhr.responseHeaders.containsKey(key)
        final body = bodyDecoded<T>(
          request,
          stringBody,
          contentType,
        );

        final response = Response<T>(
          bodyBytes: bodyBytes,
          statusCode: xhr.status,
          request: request,
          headers: xhr.responseHeaders,
          statusText: xhr.statusText,
          body: body,
          bodyString: stringBody,
        );
        completer.complete(response);
      });

      reader.onError.first.then((error) {
        completer.completeError(
          GetHttpException(error.toString(), request.url),
          StackTrace.current,
        );
      });

      reader.readAsArrayBuffer(blob);
    });

    xhr.onError.first.then((_) {
      completer.completeError(
          GetHttpException('XMLHttpRequest error.', request.url),
          StackTrace.current);
    });

    xhr.send(bytes);

    try {
      return await completer.future;
    } finally {
      _xhrs.remove(xhr);
    }
  }

  /// Closes the client and abort all active requests.
  @override
  void close() {
    for (var xhr in _xhrs) {
      xhr.abort();
    }
  }
}
